=============
:mod:`regret`
=============

Submodules
----------

`regret.emitted`
================

.. automodule:: regret.emitted
   :members:
   :undoc-members:
   :show-inheritance:


`regret.testing`
================

.. automodule:: regret.testing
   :members:
   :undoc-members:
   :show-inheritance:


Contents
--------

.. automodule:: regret
   :imported-members:
   :members:
   :undoc-members:
   :show-inheritance:
